# -*- coding: utf-8 -*-
"""
Clouvel Messages

Default: English
Future: Add ko.py, ja.py, etc. for i18n support
"""

from .en import *

# Future i18n support:
# import os
# lang = os.environ.get("CLOUVEL_LANG", "en")
# if lang == "ko":
#     from .ko import *
# elif lang == "ja":
#     from .ja import *
# else:
#     from .en import *
